==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/AgReplicaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.AgReplicaArgs.builder
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.Commit
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.Failover
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.ReadableSecondary
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.Role
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Availability group replica configuration.
 * @property commit Replica commit mode in availability group.
 * @property failover Replica failover mode in availability group.
 * @property readableSecondary Replica readable secondary mode in availability group.
 * @property role Replica Role in availability group.
 * @property sqlVirtualMachineInstanceId Sql VirtualMachine Instance Id.
 */
public data class AgReplicaArgs(
    public val commit: Output<Either<String, Commit>>? = null,
    public val failover: Output<Either<String, Failover>>? = null,
    public val readableSecondary: Output<Either<String, ReadableSecondary>>? = null,
    public val role: Output<Either<String, Role>>? = null,
    public val sqlVirtualMachineInstanceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.AgReplicaArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.AgReplicaArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.AgReplicaArgs.builder()
            .commit(
                commit?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .failover(
                failover?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .readableSecondary(
                readableSecondary?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .role(
                role?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .sqlVirtualMachineInstanceId(sqlVirtualMachineInstanceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AgReplicaArgs].
 */
@PulumiTagMarker
public class AgReplicaArgsBuilder internal constructor() {
    private var commit: Output<Either<String, Commit>>? = null

    private var failover: Output<Either<String, Failover>>? = null

    private var readableSecondary: Output<Either<String, ReadableSecondary>>? = null

    private var role: Output<Either<String, Role>>? = null

    private var sqlVirtualMachineInstanceId: Output<String>? = null

    /**
     * @param value Replica commit mode in availability group.
     */
    @JvmName("sgpjgojvyqxqqgsg")
    public suspend fun commit(`value`: Output<Either<String, Commit>>) {
        this.commit = value
    }

    /**
     * @param value Replica failover mode in availability group.
     */
    @JvmName("yytuohyvoepeyygf")
    public suspend fun failover(`value`: Output<Either<String, Failover>>) {
        this.failover = value
    }

    /**
     * @param value Replica readable secondary mode in availability group.
     */
    @JvmName("paloxaywaijmynvv")
    public suspend fun readableSecondary(`value`: Output<Either<String, ReadableSecondary>>) {
        this.readableSecondary = value
    }

    /**
     * @param value Replica Role in availability group.
     */
    @JvmName("pphmulpfskdctumt")
    public suspend fun role(`value`: Output<Either<String, Role>>) {
        this.role = value
    }

    /**
     * @param value Sql VirtualMachine Instance Id.
     */
    @JvmName("lpurkrlvjncukvck")
    public suspend fun sqlVirtualMachineInstanceId(`value`: Output<String>) {
        this.sqlVirtualMachineInstanceId = value
    }

    /**
     * @param value Replica commit mode in availability group.
     */
    @JvmName("yijommftykufdxng")
    public suspend fun commit(`value`: Either<String, Commit>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.commit = mapped
    }

    /**
     * @param value Replica commit mode in availability group.
     */
    @JvmName("woatefxeyaqccmup")
    public fun commit(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Commit>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.commit = mapped
    }

    /**
     * @param value Replica commit mode in availability group.
     */
    @JvmName("nohvvtsnsxujouup")
    public fun commit(`value`: Commit) {
        val toBeMapped = Either.ofRight<String, Commit>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.commit = mapped
    }

    /**
     * @param value Replica failover mode in availability group.
     */
    @JvmName("crnhjxekyucxcsqk")
    public suspend fun failover(`value`: Either<String, Failover>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failover = mapped
    }

    /**
     * @param value Replica failover mode in availability group.
     */
    @JvmName("xgrqymxfmvfpuvyu")
    public fun failover(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Failover>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failover = mapped
    }

    /**
     * @param value Replica failover mode in availability group.
     */
    @JvmName("ambndebyybkubvjv")
    public fun failover(`value`: Failover) {
        val toBeMapped = Either.ofRight<String, Failover>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failover = mapped
    }

    /**
     * @param value Replica readable secondary mode in availability group.
     */
    @JvmName("fdcrekovybouccmu")
    public suspend fun readableSecondary(`value`: Either<String, ReadableSecondary>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.readableSecondary = mapped
    }

    /**
     * @param value Replica readable secondary mode in availability group.
     */
    @JvmName("vieoqyvbgfagorhp")
    public fun readableSecondary(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReadableSecondary>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.readableSecondary = mapped
    }

    /**
     * @param value Replica readable secondary mode in availability group.
     */
    @JvmName("mufcxxlxvxanxvlf")
    public fun readableSecondary(`value`: ReadableSecondary) {
        val toBeMapped = Either.ofRight<String, ReadableSecondary>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.readableSecondary = mapped
    }

    /**
     * @param value Replica Role in availability group.
     */
    @JvmName("krrsbvwioearmmeu")
    public suspend fun role(`value`: Either<String, Role>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Replica Role in availability group.
     */
    @JvmName("gmerrnduyquwbiaq")
    public fun role(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Role>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Replica Role in availability group.
     */
    @JvmName("ldfqoateempxqrtr")
    public fun role(`value`: Role) {
        val toBeMapped = Either.ofRight<String, Role>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Sql VirtualMachine Instance Id.
     */
    @JvmName("rtxrqssajbxvospv")
    public suspend fun sqlVirtualMachineInstanceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlVirtualMachineInstanceId = mapped
    }

    internal fun build(): AgReplicaArgs = AgReplicaArgs(
        commit = commit,
        failover = failover,
        readableSecondary = readableSecondary,
        role = role,
        sqlVirtualMachineInstanceId = sqlVirtualMachineInstanceId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sqlvirtualmachine/kotlin/inputs/AgReplicaArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sqlvirtualmachine.kotlin.inputs

import com.pulumi.azurenative.sqlvirtualmachine.inputs.AgReplicaArgs.builder
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.Commit
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.Failover
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.ReadableSecondary
import com.pulumi.azurenative.sqlvirtualmachine.kotlin.enums.Role
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Availability group replica configuration.
 * @property commit Replica commit mode in availability group.
 * @property failover Replica failover mode in availability group.
 * @property readableSecondary Replica readable secondary mode in availability group.
 * @property role Replica Role in availability group.
 * @property sqlVirtualMachineInstanceId Sql VirtualMachine Instance Id.
 */
public data class AgReplicaArgs(
    public val commit: Output<Either<String, Commit>>? = null,
    public val failover: Output<Either<String, Failover>>? = null,
    public val readableSecondary: Output<Either<String, ReadableSecondary>>? = null,
    public val role: Output<Either<String, Role>>? = null,
    public val sqlVirtualMachineInstanceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sqlvirtualmachine.inputs.AgReplicaArgs> {
    override fun toJava(): com.pulumi.azurenative.sqlvirtualmachine.inputs.AgReplicaArgs =
        com.pulumi.azurenative.sqlvirtualmachine.inputs.AgReplicaArgs.builder()
            .commit(
                commit?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .failover(
                failover?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .readableSecondary(
                readableSecondary?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .role(
                role?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .sqlVirtualMachineInstanceId(sqlVirtualMachineInstanceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AgReplicaArgs].
 */
@PulumiTagMarker
public class AgReplicaArgsBuilder internal constructor() {
    private var commit: Output<Either<String, Commit>>? = null

    private var failover: Output<Either<String, Failover>>? = null

    private var readableSecondary: Output<Either<String, ReadableSecondary>>? = null

    private var role: Output<Either<String, Role>>? = null

    private var sqlVirtualMachineInstanceId: Output<String>? = null

    /**
     * @param value Replica commit mode in availability group.
     */
    @JvmName("cntbaaybhieofofh")
    public suspend fun commit(`value`: Output<Either<String, Commit>>) {
        this.commit = value
    }

    /**
     * @param value Replica failover mode in availability group.
     */
    @JvmName("bunuqwhslfvaanro")
    public suspend fun failover(`value`: Output<Either<String, Failover>>) {
        this.failover = value
    }

    /**
     * @param value Replica readable secondary mode in availability group.
     */
    @JvmName("jpkromxoxugpkqho")
    public suspend fun readableSecondary(`value`: Output<Either<String, ReadableSecondary>>) {
        this.readableSecondary = value
    }

    /**
     * @param value Replica Role in availability group.
     */
    @JvmName("fgxxgjwcitiowqog")
    public suspend fun role(`value`: Output<Either<String, Role>>) {
        this.role = value
    }

    /**
     * @param value Sql VirtualMachine Instance Id.
     */
    @JvmName("adyafbyulkcpbbfq")
    public suspend fun sqlVirtualMachineInstanceId(`value`: Output<String>) {
        this.sqlVirtualMachineInstanceId = value
    }

    /**
     * @param value Replica commit mode in availability group.
     */
    @JvmName("tdfyvwwvqjufikcl")
    public suspend fun commit(`value`: Either<String, Commit>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.commit = mapped
    }

    /**
     * @param value Replica commit mode in availability group.
     */
    @JvmName("jmxipgoxfyulcltk")
    public fun commit(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Commit>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.commit = mapped
    }

    /**
     * @param value Replica commit mode in availability group.
     */
    @JvmName("arapqyjuvowikqos")
    public fun commit(`value`: Commit) {
        val toBeMapped = Either.ofRight<String, Commit>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.commit = mapped
    }

    /**
     * @param value Replica failover mode in availability group.
     */
    @JvmName("avsjvlutrvlinssg")
    public suspend fun failover(`value`: Either<String, Failover>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failover = mapped
    }

    /**
     * @param value Replica failover mode in availability group.
     */
    @JvmName("sontiolrrdnltuun")
    public fun failover(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Failover>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failover = mapped
    }

    /**
     * @param value Replica failover mode in availability group.
     */
    @JvmName("dposuqxcdyrvpuwg")
    public fun failover(`value`: Failover) {
        val toBeMapped = Either.ofRight<String, Failover>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.failover = mapped
    }

    /**
     * @param value Replica readable secondary mode in availability group.
     */
    @JvmName("sqcsbxjxhoujbiiv")
    public suspend fun readableSecondary(`value`: Either<String, ReadableSecondary>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.readableSecondary = mapped
    }

    /**
     * @param value Replica readable secondary mode in availability group.
     */
    @JvmName("crwkqruiyjoajoet")
    public fun readableSecondary(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReadableSecondary>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.readableSecondary = mapped
    }

    /**
     * @param value Replica readable secondary mode in availability group.
     */
    @JvmName("swacvluutydogohs")
    public fun readableSecondary(`value`: ReadableSecondary) {
        val toBeMapped = Either.ofRight<String, ReadableSecondary>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.readableSecondary = mapped
    }

    /**
     * @param value Replica Role in availability group.
     */
    @JvmName("xpgsesribewucumr")
    public suspend fun role(`value`: Either<String, Role>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Replica Role in availability group.
     */
    @JvmName("xablnllywvaryhpj")
    public fun role(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Role>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Replica Role in availability group.
     */
    @JvmName("ftyqdvyhqkhahhgt")
    public fun role(`value`: Role) {
        val toBeMapped = Either.ofRight<String, Role>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.role = mapped
    }

    /**
     * @param value Sql VirtualMachine Instance Id.
     */
    @JvmName("gmnoqcoqpltwfqsc")
    public suspend fun sqlVirtualMachineInstanceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sqlVirtualMachineInstanceId = mapped
    }

    internal fun build(): AgReplicaArgs = AgReplicaArgs(
        commit = commit,
        failover = failover,
        readableSecondary = readableSecondary,
        role = role,
        sqlVirtualMachineInstanceId = sqlVirtualMachineInstanceId,
    )
}
